#
# spec file for package jag
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           jag
Version:        0.3.8
Release:        2.17
Summary:        Arcade and Puzzle 2D Game in which you have to break all the target pieces
# jag.xlabsoft.com is down
License:        GPL-3.0-or-later
Group:          Amusements/Games/Logic
URL:            https://gitlab.com/coringao/jag
Source0:        https://gitlab.com/coringao/jag/-/archive/%{version}/%{name}-%{version}.tar.bz2
Source2:        %{name}.appdata.xml
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5OpenGL)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(Qt5X11Extras)
BuildRequires:  pkgconfig(Qt5Xml)
BuildRequires:  pkgconfig(SDL2_mixer)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(xrandr)
Requires:       %{name}-data
%if 0%{?suse_version}
BuildRequires:  update-desktop-files
%endif

%description
The aim of JAG is to break all of the target pieces on each level,
and to do this before the time runs out. Keep doing this until you
have beaten the last level and won the game.

%package data
Summary:        Data files for the JAG game
Group:          Amusements/Games/Logic
Requires:       %{name}
Recommends:     %{name}-editor
BuildArch:      noarch

%description data
The aim of JAG is to break all of the target pieces on each level,
and to do this before the time runs out. Keep doing this until you
have beaten the last level and won the game.

Data files (bonus, help, lang, levels, schemes, sounds, tools) for JAG.

%package editor
Summary:        Level Editor for the JAG game
Group:          Amusements/Games/Logic
Requires:       %{name}
Provides:       jag-level-editor = %{version}
Obsoletes:      jag-level-editor < %{version}

%description editor
The aim of JAG is to break all of the target pieces on each level,
and to do this before the time runs out. Keep doing this until you
have beaten the last level and won the game.

This package contains the level editor for JAG.

%prep
%setup -q

# qmake...
sed -i 's#target.path = %{_prefix}/games/#target.path = %{_bindir}#' game.pro
sed -i 's#target.path = %{_prefix}/games/#target.path = %{_bindir}#' src/editor/jag-editor.pro

%build
%qmake5
pushd src/editor
%qmake5
popd

make %{?_smp_mflags}
pushd src/editor
make %{?_smp_mflags}
popd

%install
%qmake5_install
pushd src/editor
%qmake5_install
popd

# Install the desktop files
install -Dm 0644 src/jag.desktop %{buildroot}%{_datadir}/applications/%{name}.desktop

%suse_update_desktop_file -c %{name}-editor "JAG Level Editor" JAG jag-editor jag-editor "Game;LogicGame;"

# Install icons for applications menus
install -Dm 0644 src/images/jag.png %{buildroot}%{_datadir}/pixmaps/jag.png
install -Dm 0644 src/editor/jag-editor.png %{buildroot}%{_datadir}/pixmaps/jag-editor.png

# Install software gallery metadata
install -Dm 0644 %{SOURCE2} %{buildroot}%{_datadir}/appdata/%{name}.appdata.xml

%files
%license LICENSE
%doc CHANGELOG README.md
%{_bindir}/%{name}
%{_datadir}/appdata/%{name}.appdata.xml
%{_datadir}/applications/%{name}.desktop
%{_datadir}/pixmaps/jag.png

%files data
%license LICENSE
%dir %{_datadir}/games/%{name}
%{_datadir}/games/%{name}/data/

%files editor
%license LICENSE
%dir %{_datadir}/games/%{name}
%{_bindir}/jag-editor
%{_datadir}/applications/jag-editor.desktop
%{_datadir}/games/%{name}/editor/
%{_datadir}/pixmaps/jag-editor.png

%changelog
* Fri Apr 16 2021 Christophe Giboudeaux <christophe@krop.fr>
- Stop owning directories provided by the filesystem package (boo#1184786)
* Tue Sep  8 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 0.3.8
  * Warning and deprecated functions fixed in GCC.
  * game.pro: Changed to '-std=gnu++17' review.
  * src/editor/jag-editor.pro: Changed to '-std=gnu++17' review.
  * All themes have been removed, except the default theme for reasons that
    are "freeware", but with additional Fasticon restrictions.
  * Game configuration path changed.
  * Changed the position of the XCloseDisplay line.
  * About: Added contributor nickname.
* Fri May 29 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 0.3.7
  * Fixed integrated qmake support for pkg-config
  * jag-editor: Removing extra file after running the compiled binary.
- Update URL.
* Tue Mar 31 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 0.3.6
  * Project files cleanup
  * Renamed PNG image from editor.
  * Added manpage and desktop files
* Sat Dec  7 2019 Christophe Giboudeaux <christophe@krop.fr>
- Add the missing xrandr build dependency.
* Fri May  3 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 0.3.5:
  * Qt5 support added
  * SDL2 support added
  * Fixed a dbus issue
  Check the CHANGELOG file for the complete list of changes
- Change the upstream URL. The original website is down
- Run spec-cleaner
* Sun Sep 25 2016 mailaender@opensuse.org
- add appdata.xml for https://en.opensuse.org/openSUSE:AppStore
* Tue Jun 23 2015 nemysis@gmx.ch
- Update to 0.3.2, announce message:
    added Italian translation (thanks to Franco Rebora)
    added Dutch translation (thanks to Bart Van Loy)
    added French translation (thanks to Tutur)
    added "Learning ABC" level pack with 26 levels (thanks to Andrej Pohilko aka APC (http://apc.kg))
  Improvements:
    extended display settings (multi monitor recognition)
    dynamic help loading
    added menu icons
    compiled with Qt 4.7.2
- Modernize spec
- Change Summary
- Change license GPL-2.0 to GPL-3.0+
- Change Group
- Change Sources to use Web URL
- Use jag-data instead of more Sources
- Use sed instead of simple patches
- Remove patches jag-0.2.3-paths.patch and jag-0.3.1-link.patch
- Add more icons, use jag-icons.tar
- Change Desktop entry file
- Use BuildRequires pkgconfig() instead of devel packages
- Add Requires for jag-data
- Change Description
- Split out jag-data into subpackage
- Rename level-editor to jag-level-editor and split out
  jag-level-editor into separate RPM,
  because directories not owned by a package
- Fix 'File is compiled without RPM_OPT_FLAGS'
- Add Documentation
* Tue Nov  1 2011 prusnak@opensuse.org
- fix build on openSUSE 12.1+
* Fri Mar 12 2010 adam@mizerski.pl
- updated to version 0.3.1
  * added German translation (thanks to Kristjan Schmidt)
  * Fixes:
  * * broken font in dialogs with low screen resolution
  * * alternative detection of video modes on X11 if xrandr fails
  * * some compiler warnings removed
  * * some memory leaks removed
  * Improvements:
  * * main menu is centered to be visible even if JAG's main window cannot fit on the screen
* Fri Jan  1 2010 randybb@gmail.com
- updated to version 0.3.0
* Fri Nov  6 2009 randybb@gmail.com
- updated to version 0.2.6 (includes SunZero levels)
* Fri Aug 14 2009 prusnak@suse.cz
- updated to version 0.2.5
* Thu Jul 16 2009 randybb@gmail.com
- added desktop file and icon
* Wed Jul 15 2009 randybb@gmail.com
- updated to version 0.2.3
* Tue Jun 30 2009 prusnak@suse.cz
- created package (version 0.2.0)
